@@ -5,6 +5,8 @@ from typing import Sequence, Optional, Any, List
 import pyexlatex as pl
 import pyexlatex.resume as lr
 
+from derobertis_cv.pldata.constants.institutions import UF, VCU
+from derobertis_cv.pldata.courses.main import get_courses
 from derobertis_cv.pldata.employment_model import EmploymentModel
 from derobertis_cv.pltemplates.academic_employment import AcademicEmployment
 
@@ -56,25 +58,25 @@ def get_professional_jobs(excluded_companies: Optional[Sequence[str]] = None,
 
 
 def get_academic_jobs():
+
+    courses = get_courses()
+    uf_courses = [course for course in courses if course.university == UF]
+    vcu_courses = [course for course in courses if course.university == VCU]
+
     return [
         AcademicEmployment(
             [
                 'Conduct research, including project development, data collection and '
                 'cleaning, analysis, and presentation',
             ],
-            'University of Florida', 'August 2014 - Present', 'Graduate Assistant', 'Gainesville, FL',
-            courses_taught=[
-                ['Financial Modeling (Python and Excel-based course, 4.2/5.0 evaluations)', 'Fall 2019, Spring 2020'],
-                ['Debt and Money Markets (fixed income course, 4.8/5.0 evaluations)', 'Fall 2016, Spring 2018']
-            ]
+            UF, 'August 2014 - Present', 'Graduate Assistant', 'Gainesville, FL',
+            courses_taught=[course.to_cv_list() for course in uf_courses]
         ),
         AcademicEmployment(
             [
                 'Conduct research and assist professors in teaching class sections and grading assignments'
             ],
-            'Virginia Commonwealth University', 'September 2013 - August 2014', 'Graduate Assistant', 'Richmond, FL',
-            courses_taught=[
-                ['Excel Lab', 'Spring 2014']
-            ]
+            VCU, 'September 2013 - August 2014', 'Graduate Assistant', 'Richmond, FL',
+            courses_taught=[course.to_cv_list() for course in vcu_courses]
         ),
     ]
\ No newline at end of file
